.. Edsger documentation master file, created by
   sphinx-quickstart on Wed Mar 29 17:27:56 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Edsger's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Contents
--------

.. toctree::

   edsger


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
